@@ -31,3 +31,15 @@ def confirm(message=""):
     prompt_message = colourise("\nDo you want to continue? [y/N] ", Fore.LIGHTBLUE_EX)
     response = input(f"{message}{prompt_message}")
     return response.lower() in ("y", "yes")
+
+
+def confirm_dangerous_command():
+    message = (
+        "You are about to execute a dangerous command against a"
+        f" {colourise('production' , Fore.RED)} environment. Please ensure you are pairing up with"
+        " someone else."
+    )
+    # TODO. Include an actual multi person MFA to proceed.
+    if not confirm(message):
+        print(success_negative("Aborted."))
+        raise SystemExit
